@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'swift::storage::container' do
   let :pre_condition do
     "class { 'swift': swift_hash_path_suffix => 'foo' }
-     class { 'swift::storage': storage_local_net_ip => '10.0.0.1' }"
+     class { 'swift::storage::all': storage_local_net_ip => '10.0.0.1' }"
   end
 
   let :params do
